@@ -1,33 +1,38 @@
 import json
-from typing import Dict, List, Set
+from typing import Dict, Generator, List, Set
 
 from linkml_validator.models import ValidationReport
 from linkml_validator.plugins.base import BasePlugin
-from linkml_validator.plugins.jsonschema_validation import JsonschemaValidationPlugin
+from linkml_validator.plugins.jsonschema_validation import JsonSchemaValidationPlugin
 
 
 DEFAULT_PLUGINS = {
-    "JsonschemaValidationPlugin": JsonschemaValidationPlugin
+    "JsonschemaValidationPlugin": JsonSchemaValidationPlugin
 }
 
 
 class Validator:
     """
-    Metadata Validator to validate data against a given schema.
+    Validator to validate data against a given schema.
 
-    :param schema: Path or URL to schema YAML
-    :param plugins: A set of plugin classes to use for validation
+    Args:
+        schema: Path or URL to schema YAML
+        plugins: A set of plugin classes to use for validation
 
     """
 
-    def __init__(self, schema: str, plugins: Set[BasePlugin] = None) -> None:
+    def __init__(self, schema: str, plugins: List[Dict] = None) -> None:
         self.schema = schema
         self.plugins = set()
         if plugins:
-            for plugin_class in plugins:
+            for plugin in plugins:
+                plugin_class = plugin["plugin_class"]
+                plugin_args = {}
+                if "args" in plugin:
+                    plugin_args = plugin["args"]
                 if not issubclass(plugin_class, BasePlugin):
                     raise Exception(f"{plugin_class} must be a subclass of {BasePlugin}")
-                instance = plugin_class(schema=self.schema)
+                instance = plugin_class(schema=self.schema, **plugin_args)
                 self.plugins.add(instance)
         else:
             for plugin_class in DEFAULT_PLUGINS.values():
@@ -35,29 +40,37 @@ class Validator:
                 self.plugins.add(instance)
 
     def validate(
-        self, obj: Dict, target_class: str, strict: bool = False
+        self, obj: Dict, target_class: str, strict: bool = False, **kwargs
     ) -> ValidationReport:
         """
         Validate an object.
 
-        :param obj: The object to validate
-        :param target_class: The type of object
-        :param strict: Whether or not to perform strict validation, where any validation
-            error stops the validation process. Defaults to False.
-        :return: A validation report that summarizes the validation
+        Args:
+            obj: The object to validate
+            target_class: The type of object
+            strict: Whether or not to perform strict validation, where any validation
+                error stops the validation process. Defaults to `False`.
+            kwargs: Any additional arguments
+
+        Returns:
+            ValidationReport: A validation report that summarizes the validation
 
         """
         validation_results = []
         valid = True
+        if "exclude_object" in kwargs:
+            exclude_object = kwargs["exclude_object"]
+        else:
+            exclude_object = False
         for plugin in self.plugins:
-            validation_result = plugin.process(obj=obj, target_class=target_class)
+            validation_result = plugin.process(obj=obj, target_class=target_class, **kwargs)
             validation_results.append(validation_result)
             if not validation_result.valid:
                 valid = False
                 if strict:
                     break
         validation_report = ValidationReport(
-            object=obj,
+            object=obj if not exclude_object else None,
             type=target_class,
             valid=valid,
             validation_results=validation_results,
@@ -66,18 +79,20 @@ class Validator:
 
     def validate_file(
         self, filename: str, target_class: str = None, strict: bool = False
-    ) -> List[ValidationReport]:
+    ) -> Generator:
         """
-        Validate all objets from a file.
+        Validate all objects from a file.
 
-        :param filename: The filename
-        :param target_class: The target class which all objects from the input JSON are an instance of
-        :param strict: Whether or not to perform strict validation, where any validation
-            error stops the validation process. Defaults to False.
-        :return: A list of validation reports that summarizes the validation
+        Args:
+            filename: The filename
+            target_class: The target class which all objects from the input JSON are an instance of
+            strict: Whether or not to perform strict validation, where any validation
+                error stops the validation process. Defaults to `False`.
+
+        Returns:
+            Generator: A generator that can be iterated to get a list of validation reports
 
         """
-        reports = []
         with open(filename, "r", encoding="UTF-8") as file:
             data = json.load(file)
             if isinstance(data, list):
@@ -86,7 +101,7 @@ class Validator:
                         report = self.validate(
                             obj=obj, target_class=target_class, strict=strict
                         )
-                        reports.append(report)
+                        yield report
                 else:
                     raise Exception(f"target_class not defined. Cannot validate array of objects from {filename}.")
             else:
@@ -95,5 +110,4 @@ class Validator:
                         report = self.validate(
                             obj=obj, target_class=target_class, strict=strict
                         )
-                        reports.append(report)
-        return reports
+                        yield report
